Type: Package
Package: circumplex
Title: Analysis and Visualization of Circular Data
Version: 1.1.0
Authors@R: 
    c(person(given = "Jeffrey",
             family = "Girard",
             role = c("aut", "cre"),
             email = "me@jmgirard.com",
             comment = c(ORCID = "0000-0002-7359-3746")),
      person(given = "Johannes",
             family = "Zimmermann",
             role = "aut",
             comment = c(ORCID = "0000-0001-6975-2356")),
      person(given = "Aidan",
             family = "Wright",
             role = "aut",
             comment = c(ORCID = "0000-0002-2369-0601")))
Description: Circumplex models, which organize constructs in a circle around two 
    underlying dimensions, are popular for studying interpersonal functioning, 
    mood/affect, and vocational preferences/environments. This package provides 
    tools for analyzing and visualizing circular data, including scoring 
    functions for relevant instruments and a generalization of the bootstrapped 
    structural summary method from Zimmermann & Wright (2017) 
    <doi:10.1177/1073191115621795> and functions for creating publication-ready 
    tables and figures from the results.
License: GPL-3
URL: https://github.com/jmgirard/circumplex,
        http://circumplex.jmgirard.com/
BugReports: https://github.com/jmgirard/circumplex/issues
Depends: R (>= 3.4)
Imports: boot (>= 1.3-18), ggforce (>= 0.3.0), ggplot2 (>= 3.3.0),
        htmlTable (>= 1.13.3), Rcpp, rlang, stats
Suggests: covr (>= 3.5.0), ggrepel, kableExtra (>= 1.1.0), knitr (>=
        1.28), RColorBrewer, rmarkdown (>= 2.1), roxygen2 (>= 7.1.0),
        testthat (>= 3.0.0), vdiffr
LinkingTo: Rcpp, RcppArmadillo (>= 0.11)
VignetteBuilder: knitr
Encoding: UTF-8
LazyData: true
Config/testthat/edition: 3
Config/roxygen2/version: 8.0.0
NeedsCompilation: yes
Packaged: 2026-05-24 19:35:57 UTC; jmgirard
Author: Jeffrey Girard [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7359-3746>),
  Johannes Zimmermann [aut] (ORCID:
    <https://orcid.org/0000-0001-6975-2356>),
  Aidan Wright [aut] (ORCID: <https://orcid.org/0000-0002-2369-0601>)
Maintainer: Jeffrey Girard <me@jmgirard.com>
Repository: CRAN
Date/Publication: 2026-05-24 20:00:02 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-05-25 02:08:01 UTC; unix
Archs: circumplex.so.dSYM
