# Generated by roxygen2: do not edit by hand

S3method(as_degree,circumplex_degree)
S3method(as_degree,circumplex_radian)
S3method(as_degree,default)
S3method(as_radian,circumplex_degree)
S3method(as_radian,circumplex_radian)
S3method(as_radian,default)
S3method(print,circumplex_degree)
S3method(print,circumplex_instrument)
S3method(print,circumplex_radian)
S3method(print,circumplex_ssm)
S3method(quantile,circumplex_contrast_radian)
S3method(quantile,circumplex_radian)
S3method(summary,circumplex_instrument)
S3method(summary,circumplex_ssm)
export(PANO)
export(anchors)
export(ggsave)
export(html_render)
export(instruments)
export(ipsatize)
export(items)
export(norm_standardize)
export(norms)
export(octants)
export(poles)
export(quadrants)
export(scales)
export(score)
export(self_standardize)
export(ssm_analyze)
export(ssm_parameters)
export(ssm_plot_circle)
export(ssm_plot_contrast)
export(ssm_plot_curve)
export(ssm_score)
export(ssm_table)
importFrom(Rcpp,sourceCpp)
importFrom(ggplot2,ggsave)
importFrom(rlang,.data)
importFrom(stats,quantile)
useDynLib(circumplex, .registration = TRUE)
