# unit classes are working

    Code
      octants()
    Output
      90 135 180 225 270 315 360 45 
      Degrees

---

    Code
      as_radian(octants())
    Output
      1.571 2.356 3.142 3.927 4.712 5.498 6.283 0.785 
      Radians

