# The print method for the S3 instrument class produces the right output

    ISC: Interpersonal Sensitivities Circumplex
    64 items, 8 scales, 1 normative data sets
    Hopwood et al. (2011)
    <https://doi.org/10.1111/j.1467-6494.2011.00696.x>

# The summary method for the S3 instrument class produces the right output

    ISC: Interpersonal Sensitivities Circumplex
    64 items, 8 scales, 1 normative data sets
    Hopwood et al. (2011)
    <https://doi.org/10.1111/j.1467-6494.2011.00696.x>
    
    The ISC contains 8 circumplex scales.
    PA: Sensitive to Control (90 degrees)
    BC: Sensitive to Antagonism (135 degrees)
    DE: Sensitive to Remoteness (180 degrees)
    FG: Sensitive to Timidity (225 degrees)
    HI: Sensitive to Passivity (270 degrees)
    JK: Sensitive to Dependence (315 degrees)
    LM: Sensitive to Affection (360 degrees)
    NO: Sensitive to Attention-Seeking (45 degrees)
    
    The ISC is rated using the following 8-point scale.
    1. Not at all, never bothers me
    2. Very little, rarely bothers me
    3. A little, occasionally bothers me
    4. Slightly, bothers me less than half the time
    5. Somewhat, bothers me more than half of the time
    6. Quite, bothers me frequently
    7. Very much, bothers me most of the time
    8. Extremely, always bothers me
    
    The ISC contains 64 items (open-access):
    Prefix: It bothers me when a person...
    1. Thinks they are my boss
    2. Disregards my feelings
    3. Doesn't show any feelings
    4. Won't engage in conversation
    5. Cannot assert themselves
    6. Avoids conflict at all costs
    7. Wants to spend lots of time with me
    8. Doesn't respect my privacy
    9. Orders me around
    10. Doesn't respond to me
    11. Doesn't want to be friends
    12. Is aloof
    13. Doesn't have a backbone
    14. Always needs support
    15. Tries to get close to me really fast
    16. Talks themselves up
    17. Talks down to me
    18. Is hostile
    19. Walls themselves off from me
    20. Acts like a wallflower
    21. Is weak
    22. Always seems to need my help
    23. Tells me they love me
    24. Shows off
    25. Will do anything to get what they want
    26. Is deceitful
    27. Won't share their feelings with me
    28. Won't step up to the plate
    29. Allows themselves to be dominated by others
    30. Acts helpless
    31. Expresses concern about me
    32. Talks about themselves
    33. Has to call the shots
    34. Mistrusts me
    35. Is unresponsive
    36. Doesn't share their ideas
    37. Is always submissive
    38. Laughs at all my jokes
    39. Acts like we're friends when we don't even know each other
    40. Has to be right
    41. Intimidates me
    42. Doesn't care about my feelings
    43. Avoids me
    44. Won't participate
    45. Cannot make decisions
    46. Is dependent on me
    47. Humors me
    48. Interrupts
    49. Is bossy
    50. Expects the worst out of me
    51. Never gets in touch with me
    52. Is really shy
    53. Is very passive
    54. Believes everything I say
    55. Believes I can do no wrong
    56. Tries to show me how to do things
    57. Always puts themselves first
    58. Is mean-spirited
    59. Pulls away from me
    60. Refuses to lead
    61. Is easily controlled
    62. Is soft
    63. Is clingy
    64. Takes control
    
    The ISC currently has 1 normative data set(s):
    1. 649 American college students
    Hopwood et al. (2011)
    <https://doi.org/10.1111/j.1467-6494.2011.00696.x>

---

    ISC: Interpersonal Sensitivities Circumplex
    64 items, 8 scales, 1 normative data sets
    Hopwood et al. (2011)
    <https://doi.org/10.1111/j.1467-6494.2011.00696.x>

---

    ISC: Interpersonal Sensitivities Circumplex
    64 items, 8 scales, 1 normative data sets
    Hopwood et al. (2011)
    <https://doi.org/10.1111/j.1467-6494.2011.00696.x>
    
    The ISC contains 8 circumplex scales.
    PA: Sensitive to Control (90 degrees)
    BC: Sensitive to Antagonism (135 degrees)
    DE: Sensitive to Remoteness (180 degrees)
    FG: Sensitive to Timidity (225 degrees)
    HI: Sensitive to Passivity (270 degrees)
    JK: Sensitive to Dependence (315 degrees)
    LM: Sensitive to Affection (360 degrees)
    NO: Sensitive to Attention-Seeking (45 degrees)

---

    ISC: Interpersonal Sensitivities Circumplex
    64 items, 8 scales, 1 normative data sets
    Hopwood et al. (2011)
    <https://doi.org/10.1111/j.1467-6494.2011.00696.x>
    
    The ISC is rated using the following 8-point scale.
    1. Not at all, never bothers me
    2. Very little, rarely bothers me
    3. A little, occasionally bothers me
    4. Slightly, bothers me less than half the time
    5. Somewhat, bothers me more than half of the time
    6. Quite, bothers me frequently
    7. Very much, bothers me most of the time
    8. Extremely, always bothers me

---

    ISC: Interpersonal Sensitivities Circumplex
    64 items, 8 scales, 1 normative data sets
    Hopwood et al. (2011)
    <https://doi.org/10.1111/j.1467-6494.2011.00696.x>
    
    The ISC contains 64 items (open-access):
    Prefix: It bothers me when a person...
    1. Thinks they are my boss
    2. Disregards my feelings
    3. Doesn't show any feelings
    4. Won't engage in conversation
    5. Cannot assert themselves
    6. Avoids conflict at all costs
    7. Wants to spend lots of time with me
    8. Doesn't respect my privacy
    9. Orders me around
    10. Doesn't respond to me
    11. Doesn't want to be friends
    12. Is aloof
    13. Doesn't have a backbone
    14. Always needs support
    15. Tries to get close to me really fast
    16. Talks themselves up
    17. Talks down to me
    18. Is hostile
    19. Walls themselves off from me
    20. Acts like a wallflower
    21. Is weak
    22. Always seems to need my help
    23. Tells me they love me
    24. Shows off
    25. Will do anything to get what they want
    26. Is deceitful
    27. Won't share their feelings with me
    28. Won't step up to the plate
    29. Allows themselves to be dominated by others
    30. Acts helpless
    31. Expresses concern about me
    32. Talks about themselves
    33. Has to call the shots
    34. Mistrusts me
    35. Is unresponsive
    36. Doesn't share their ideas
    37. Is always submissive
    38. Laughs at all my jokes
    39. Acts like we're friends when we don't even know each other
    40. Has to be right
    41. Intimidates me
    42. Doesn't care about my feelings
    43. Avoids me
    44. Won't participate
    45. Cannot make decisions
    46. Is dependent on me
    47. Humors me
    48. Interrupts
    49. Is bossy
    50. Expects the worst out of me
    51. Never gets in touch with me
    52. Is really shy
    53. Is very passive
    54. Believes everything I say
    55. Believes I can do no wrong
    56. Tries to show me how to do things
    57. Always puts themselves first
    58. Is mean-spirited
    59. Pulls away from me
    60. Refuses to lead
    61. Is easily controlled
    62. Is soft
    63. Is clingy
    64. Takes control

---

    ISC: Interpersonal Sensitivities Circumplex
    64 items, 8 scales, 1 normative data sets
    Hopwood et al. (2011)
    <https://doi.org/10.1111/j.1467-6494.2011.00696.x>
    
    The ISC currently has 1 normative data set(s):
    1. 649 American college students
    Hopwood et al. (2011)
    <https://doi.org/10.1111/j.1467-6494.2011.00696.x>

# The sub-summary functions produce the expected output

    The ISC contains 8 circumplex scales.
    PA: Sensitive to Control (90 degrees)
    BC: Sensitive to Antagonism (135 degrees)
    DE: Sensitive to Remoteness (180 degrees)
    FG: Sensitive to Timidity (225 degrees)
    HI: Sensitive to Passivity (270 degrees)
    JK: Sensitive to Dependence (315 degrees)
    LM: Sensitive to Affection (360 degrees)
    NO: Sensitive to Attention-Seeking (45 degrees)

---

    The ISC contains 8 circumplex scales.
    PA: Sensitive to Control (90 degrees)
        1. Thinks they are my boss
        9. Orders me around
        17. Talks down to me
        25. Will do anything to get what they want
        33. Has to call the shots
        41. Intimidates me
        49. Is bossy
        57. Always puts themselves first
    BC: Sensitive to Antagonism (135 degrees)
        2. Disregards my feelings
        10. Doesn't respond to me
        18. Is hostile
        26. Is deceitful
        34. Mistrusts me
        42. Doesn't care about my feelings
        50. Expects the worst out of me
        58. Is mean-spirited
    DE: Sensitive to Remoteness (180 degrees)
        3. Doesn't show any feelings
        11. Doesn't want to be friends
        19. Walls themselves off from me
        27. Won't share their feelings with me
        35. Is unresponsive
        43. Avoids me
        51. Never gets in touch with me
        59. Pulls away from me
    FG: Sensitive to Timidity (225 degrees)
        4. Won't engage in conversation
        12. Is aloof
        20. Acts like a wallflower
        28. Won't step up to the plate
        36. Doesn't share their ideas
        44. Won't participate
        52. Is really shy
        60. Refuses to lead
    HI: Sensitive to Passivity (270 degrees)
        5. Cannot assert themselves
        13. Doesn't have a backbone
        21. Is weak
        29. Allows themselves to be dominated by others
        37. Is always submissive
        45. Cannot make decisions
        53. Is very passive
        61. Is easily controlled
    JK: Sensitive to Dependence (315 degrees)
        6. Avoids conflict at all costs
        14. Always needs support
        22. Always seems to need my help
        30. Acts helpless
        38. Laughs at all my jokes
        46. Is dependent on me
        54. Believes everything I say
        62. Is soft
    LM: Sensitive to Affection (360 degrees)
        7. Wants to spend lots of time with me
        15. Tries to get close to me really fast
        23. Tells me they love me
        31. Expresses concern about me
        39. Acts like we're friends when we don't even know each other
        47. Humors me
        55. Believes I can do no wrong
        63. Is clingy
    NO: Sensitive to Attention-Seeking (45 degrees)
        8. Doesn't respect my privacy
        16. Talks themselves up
        24. Shows off
        32. Talks about themselves
        40. Has to be right
        48. Interrupts
        56. Tries to show me how to do things
        64. Takes control

---

    The ISC contains 64 items (open-access):
    Prefix: It bothers me when a person...
    1. Thinks they are my boss
    2. Disregards my feelings
    3. Doesn't show any feelings
    4. Won't engage in conversation
    5. Cannot assert themselves
    6. Avoids conflict at all costs
    7. Wants to spend lots of time with me
    8. Doesn't respect my privacy
    9. Orders me around
    10. Doesn't respond to me
    11. Doesn't want to be friends
    12. Is aloof
    13. Doesn't have a backbone
    14. Always needs support
    15. Tries to get close to me really fast
    16. Talks themselves up
    17. Talks down to me
    18. Is hostile
    19. Walls themselves off from me
    20. Acts like a wallflower
    21. Is weak
    22. Always seems to need my help
    23. Tells me they love me
    24. Shows off
    25. Will do anything to get what they want
    26. Is deceitful
    27. Won't share their feelings with me
    28. Won't step up to the plate
    29. Allows themselves to be dominated by others
    30. Acts helpless
    31. Expresses concern about me
    32. Talks about themselves
    33. Has to call the shots
    34. Mistrusts me
    35. Is unresponsive
    36. Doesn't share their ideas
    37. Is always submissive
    38. Laughs at all my jokes
    39. Acts like we're friends when we don't even know each other
    40. Has to be right
    41. Intimidates me
    42. Doesn't care about my feelings
    43. Avoids me
    44. Won't participate
    45. Cannot make decisions
    46. Is dependent on me
    47. Humors me
    48. Interrupts
    49. Is bossy
    50. Expects the worst out of me
    51. Never gets in touch with me
    52. Is really shy
    53. Is very passive
    54. Believes everything I say
    55. Believes I can do no wrong
    56. Tries to show me how to do things
    57. Always puts themselves first
    58. Is mean-spirited
    59. Pulls away from me
    60. Refuses to lead
    61. Is easily controlled
    62. Is soft
    63. Is clingy
    64. Takes control

---

    The ISC is rated using the following 8-point scale.
    1. Not at all, never bothers me
    2. Very little, rarely bothers me
    3. A little, occasionally bothers me
    4. Slightly, bothers me less than half the time
    5. Somewhat, bothers me more than half of the time
    6. Quite, bothers me frequently
    7. Very much, bothers me most of the time
    8. Extremely, always bothers me

---

    The ISC currently has 1 normative data set(s):
    1. 649 American college students
    Hopwood et al. (2011)
    <https://doi.org/10.1111/j.1467-6494.2011.00696.x>

# The instruments function produces the expected output

    The circumplex package currently includes 14 instruments:
     1. CAIS: Child and Adolescent Interpersonal Survey (cais)
     2. CSIE: Circumplex Scales of Interpersonal Efficacy (csie)
     3. CSIG: Circumplex Scales of Intergroup Goals (csig)
     4. CSIP: Circumplex Scales of Interpersonal Problems (csip)
     5. CSIV: Circumplex Scales of Interpersonal Values (csiv)
     6. IEI: Interpersonal Emotion Inventory (iei)
     7. IGI-CR: Interpersonal Goals Inventory for Children, Revised Version (igicr)
     8. IIP-32: Inventory of Interpersonal Problems, Brief Version (iip32)
     9. IIP-64: Inventory of Interpersonal Problems (iip64)
     10. IIP-SC: Inventory of Interpersonal Problems, Short Circumplex (iipsc)
     11. IIS-32: Inventory of Interpersonal Strengths, Brief Version (iis32)
     12. IIS-64: Inventory of Interpersonal Strengths (iis64)
     13. IIT-C: Inventory of Influence Tactics Circumplex (iitc)
     14. IPIP-IPC: IPIP Interpersonal Circumplex (ipipipc)
     15. ISC: Interpersonal Sensitivities Circumplex (isc)

