% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/instrument_data.R
\docType{data}
\name{ipipipc}
\alias{ipipipc}
\title{IPIP Interpersonal Circumplex}
\format{
An object of class \code{circumplex_instrument} of length 5.
}
\source{
Markey, P. M., & Markey, C. N. (2009). A brief assessment of the
interpersonal circumplex: The IPIP-IPC. \emph{Assessment, 16}(4), 352-361.

\doi{10.1177/1073191109340382}
}
\usage{
ipipipc
}
\description{
Information about the IPIP Interpersonal Circumplex (IPIP-IPC).
}
\examples{
summary(ipipipc)
scales(ipipipc, items = TRUE)
}
\keyword{internal}
