% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/instrument_data.R
\docType{data}
\name{iipsc}
\alias{iipsc}
\title{Inventory of Interpersonal Problems, Short Circumplex}
\format{
An object of class \code{circumplex_instrument} of length 5.
}
\source{
Soldz, S., Budman, S., Demby, A., & Merry, J. (1995). A short form of
the Inventory of Interpersonal Problems Circumplex Scales. \emph{Assessment,
2}(1), 53-63.

\doi{10.1080/00223890802388665}
}
\usage{
iipsc
}
\description{
Information about the Inventory of Interpersonal Problems Short Circumplex
(IIP-SC).
}
\examples{
summary(iipsc)
}
\keyword{internal}
