% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/instrument_data.R
\docType{data}
\name{iei}
\alias{iei}
\title{Interpersonal Emotion Inventory}
\format{
An object of class \code{circumplex_instrument} of length 5.
}
\source{
Horner, M. S., Locke, K. D., & Hulsey, T. L. (in press). Assessing
affective dimensions of the interpersonal circumplex: development and
validation of the interpersonal emotion inventory. \emph{Journal of Personality
Assessment}. Advanced online publication.

\doi{10.1080/00223891.2024.2400266}

\url{https://kennethlocke.org/IEI/IEI.html}
}
\usage{
iei
}
\description{
Information about the Interpersonal Emotion Inventory (IEI).
}
\examples{
summary(iei)
scales(iei, items = TRUE)
}
\keyword{internal}
