% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{ggsave}
\alias{ggsave}
\title{Save a ggplot with sensible defaults}
\description{
See \code{ggplot2} for details.
}
\keyword{internal}
