% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/instrument_oop.R
\name{instruments}
\alias{instruments}
\title{List all available instruments}
\usage{
instruments()
}
\description{
The circumplex package includes information about numerous circumplex
instruments including instructions for scoring and standardizing items.
Individual instruments can be loaded using the \code{instrument} function.
}
\examples{
instruments()
}
\seealso{
Other instrument functions: 
\code{\link{anchors}()},
\code{\link{items}()},
\code{\link{norms}()},
\code{\link{scales}()}
}
\concept{instrument functions}
