% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/convenience_functions.R
\name{quadrants}
\alias{quadrants}
\title{Angular displacements for quadrant circumplex scales}
\usage{
quadrants()
}
\value{
A numeric vector with eight elements, each corresponding to the
angular displacement (in degrees) of a subscale, in the following order:
BC, FG, JK, NO.
}
\description{
Return a vector of angular displacements, in degrees, for four equally spaced
circumplex scales corresponding to the circumplex quadrants. Can be passed to
the \code{angles} parameter of other functions in this package.
}
\examples{
quadrants()
}
