% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/convenience_functions.R
\name{PANO}
\alias{PANO}
\title{Two-letter abbreviations for octant circumplex scales}
\usage{
PANO(case = "upper")
}
\arguments{
\item{case}{An optional string the determines whether the abbreviations should be
in uppercase or lowercase. (default = "upper")}
}
\value{
A character vector with eight elements, each corresponding to the
abbreviation of an octant subscale: PA, BC, DE, FG, HI, JK, LM, NO.
}
\description{
Return a vector of abbreviations for octant circumplex scales, from PA to NO.
}
\examples{
PANO()
PANO(case = "lower")

}
