% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/instrument_data.R
\docType{data}
\name{iis64}
\alias{iis64}
\title{Inventory of Interpersonal Strengths}
\format{
An object of class \code{circumplex_instrument} of length 5.
}
\source{
Hatcher, R. L., & Rogers, D. T. (2009). Development and validation of
a measure of interpersonal strengths: The Inventory of Interpersonal
Strengths. \emph{Psychological Assessment, 21}(4), 554-569.

\doi{10.1037/a0017269}
}
\usage{
iis64
}
\description{
Information about the Inventory of Interpersonal Strengths (IIS-64).
}
\examples{
summary(iis64)
scales(iis64, items = TRUE)
}
\keyword{internal}
