% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/instrument_oop.R
\name{anchors}
\alias{anchors}
\title{Display the anchors of a circumplex instrument}
\usage{
anchors(x)
}
\arguments{
\item{x}{Required. An object of the instrument class.}
}
\value{
The same input object. Prints text to console.
}
\description{
Display the anchors of a circumplex instrument including the total number of
anchors and each anchor's numerical value and text label. Anchors are the
response options that respondants select from (e.g., 0 = No, 1 = Yes).
}
\examples{
anchors(csip)
}
\seealso{
Other instrument functions: 
\code{\link{instruments}()},
\code{\link{items}()},
\code{\link{norms}()},
\code{\link{scales}()}
}
\concept{instrument functions}
