% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/example_data.R
\docType{data}
\name{aw2009}
\alias{aw2009}
\title{Standardized octant scores on hypothetical circumplex scales}
\format{
A data frame with 5 observations and 8 variables:
\describe{
\item{PA}{circumplex scale at 90 degrees}
\item{BC}{circumplex scale at 135 degrees}
\item{DE}{circumplex scale at 180 degrees}
\item{FG}{circumplex scale at 225 degrees}
\item{HI}{circumplex scale at 270 degrees}
\item{JK}{circumplex scale at 315 degrees}
\item{LM}{circumplex scale at 360 degrees}
\item{NO}{circumplex scale at 45 degrees}
}
}
\source{
\doi{10.1080/00223890902935696}
}
\usage{
aw2009
}
\description{
A small example dataset containing standardized scores on eight hypothetical
circumplex scales. Taken from Wright, Pincus, Conroy, & Hilsenroth (2009).
}
\keyword{datasets}
