% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/example_data.R
\docType{data}
\name{raw_iipsc}
\alias{raw_iipsc}
\title{Raw item responses on real circumplex scales}
\format{
A data frame with 10 observations and 32 variables.
}
\usage{
raw_iipsc
}
\description{
A small example dataset containing raw item responses on the Inventory of
Interpersonal Problems, Short Circumplex (IIP-SC). This data set is useful
for testing functions that operate on item-level data.
}
\keyword{datasets}
