% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/instrument_data.R
\docType{data}
\name{csig}
\alias{csig}
\title{Circumplex Scales of Intergroup Goals}
\format{
An object of class \code{circumplex_instrument} of length 5.
}
\source{
Locke, K. D. (2014). Circumplex scales of intergroup goals: An
interpersonal circle model of goals for interactions between groups.
\emph{Personality and Social Psychology Bulletin, 40}(4), 433-449.

\url{https://kennethlocke.org/CSIG/CSIG.html}
}
\usage{
csig
}
\description{
Information about the Circumplex Scales of Intergroup Goals (CSIG).
}
\examples{
summary(csig)
scales(csig, items = TRUE)
}
\keyword{internal}
