% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/instrument_oop.R
\name{items}
\alias{items}
\title{Display the items of a circumplex instrument}
\usage{
items(x)
}
\arguments{
\item{x}{Required. An object of the instrument class.}
}
\value{
The same input object. Prints text to console.
}
\description{
Display the items of a circumplex instrument including the total number of
items and each item's number and text. The item ordering/numbering displayed
here is the same ordering/numbering assumed by the \code{score()} function.
}
\examples{
items(csip)
}
\seealso{
Other instrument functions: 
\code{\link{anchors}()},
\code{\link{instruments}()},
\code{\link{norms}()},
\code{\link{scales}()}
}
\concept{instrument functions}
