% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/instrument_data.R
\docType{data}
\name{iitc}
\alias{iitc}
\title{Inventory of Influence Tactics Circumplex}
\format{
An object of class \code{circumplex_instrument} of length 5.
}
\source{
Bliton, C. F., & Pincus, A. L. (in press). Construction and
Validation of the Interpersonal Influence Tactics Circumplex (IIT-C)
Scales. \emph{Assessment}.

\doi{10.1177/1073191119864661}
}
\usage{
iitc
}
\description{
Information about the Inventory of Influence Tactics Circumplex (IIT-C).
}
\examples{
summary(iitc)
scales(iitc, items = TRUE)
}
\keyword{internal}
