% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/example_data.R
\docType{data}
\name{jz2017}
\alias{jz2017}
\title{Raw octant scores on real circumplex scales with covariates}
\format{
A data frame with 1166 observations and 19 variables:
\describe{
\item{Gender}{Self-reported Gender}
\item{PA}{Domineering Problems (IIP-SC) 90 degrees}
\item{BC}{Vindictive Problems (IIP-SC) 135 degrees}
\item{DE}{Cold Problems (IIP-SC) 180 degrees}
\item{FG}{Socially Avoidant Problems (IIP-SC) 225 degrees}
\item{HI}{Nonassertive Problems(IIP-SC) 270 degrees}
\item{JK}{Easily Exploited Problems (IIP-SC) 315 degrees}
\item{LM}{Overly Nurturant Problems (IIP-SC) 360 degrees}
\item{NO}{Intrusive Problems (IIP-SC) 45 degrees}
\item{PARPD}{Paranoid PD Symptoms (PDQ-4+)}
\item{SCZPD}{Schizoid PD Symptoms (PDQ-4+)}
\item{SZTPD}{Schizotypal PD Symptoms (PDQ-4+)}
\item{ASPD}{Antisocial PD Symptoms (PDQ-4+)}
\item{BORPD}{Borderline PD Symptoms (PDQ-4+)}
\item{HISPD}{Histrionic PD Symptoms (PDQ-4+)}
\item{NARPD}{Narcissistic PD Symptoms (PDQ-4+)}
\item{AVPD}{Avoidant PD Symptoms (PDQ-4+)}
\item{DPNPD}{Dependent PD Symptoms (PDQ-4+)}
\item{OCPD}{Obsessive-Compulsive PD Symptoms (PDQ-4+)}
}
}
\source{
\doi{10.1177/1073191115621795}
}
\usage{
jz2017
}
\description{
A large example dataset containing gender, raw mean scores on the Inventory
of Interpersonal Problems - Short Circumplex (IIP-SC), and raw sum scores on
the Personality Diagnostic Questionnaire - 4th Edition Plus (PDQ-4+).
}
\keyword{datasets}
