% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/convenience_functions.R
\name{poles}
\alias{poles}
\title{Angular displacements for pole circumplex scales}
\usage{
poles()
}
\value{
A numeric vector with four elements, each corresponding to the
angular displacement (in degrees) of a subscale, in the following order:
PA, DE, HI, LM.
}
\description{
Return a vector of angular displacements, in degrees, for four equally spaced
circumplex scales corresponding to the circumplex poles. Can be passed to the
\code{angles} parameter of other functions in this package.
}
\examples{
poles()
}
