% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/instrument_data.R
\docType{data}
\name{cais}
\alias{cais}
\title{Child and Adolescent Interpersonal Survey}
\format{
An object of class \code{circumplex_instrument} of length 5.
}
\source{
Sodano, S. M., & Tracey, T. J. G. (2006). Interpersonal traits in
childhood: Development of the Child and Adolescent Interpersonal Survey.
\emph{Journal of Personality Assessment, 87}(3), 317–329.

\doi{10.1207/s15327752jpa8703_12}
}
\usage{
cais
}
\description{
Information about the Child and Adolescent Interpersonal Survey (CAIS).
}
\examples{
summary(cais)
scales(cais, items = TRUE)
}
\keyword{internal}
