% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/instrument_data.R
\docType{data}
\name{csie}
\alias{csie}
\title{Circumplex Scales of Interpersonal Efficacy}
\format{
An object of class \code{circumplex_instrument} of length 5.
}
\source{
Locke, K. D., & Sadler, P. (2007). Self-efficacy, values, and
complementarity in dyadic interactions: Integrating interpersonal and
social-cognitive theory. \emph{Personality and Social Psychology Bulletin,
33}(1), 94-109.

\url{https://kennethlocke.org/CSIE/CSIE.html}
}
\usage{
csie
}
\description{
Information about the Circumplex Scales of Interpersonal Efficacy (CSIE).
}
\examples{
summary(csie)
scales(csie, items = TRUE)
}
\keyword{internal}
