% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/instrument_data.R
\docType{data}
\name{igicr}
\alias{igicr}
\title{Interpersonal Goals Inventory for Children, Revised Version}
\format{
An object of class \code{circumplex_instrument} of length 5.
}
\source{
Trucco, E. M., Wright, A. G. C., & Colder, C. R. (2013). A revised
interpersonal circumplex inventory of children’s social goals. \emph{Assessment,
20}(1), 98-113.

\doi{10.1177/1073191111411672}
}
\usage{
igicr
}
\description{
Information about the Interpersonal Goals Inventory for Children, Revised
Version (IGI-CR).
}
\examples{
summary(igicr)
scales(igicr, items = TRUE)
}
\keyword{internal}
