% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/instrument_oop.R
\name{norms}
\alias{norms}
\title{Display the norms for a circumplex instrument}
\usage{
norms(x)
}
\arguments{
\item{x}{Required. An object of the instrument class.}
}
\value{
The same input object. Prints text to console.
}
\description{
Display the norms for a circumplex instrument including the total number of
normative data sets available and each data set's number, sample size,
population, and source reference and hyperlink. If another normative data set
exists that is not yet included in the package, please let us know.
}
\examples{
norms(csip)
}
\seealso{
Other instrument functions: 
\code{\link{anchors}()},
\code{\link{instruments}()},
\code{\link{items}()},
\code{\link{scales}()}
}
\concept{instrument functions}
