% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/convenience_functions.R
\name{octants}
\alias{octants}
\title{Angular displacements for octant circumplex scales}
\usage{
octants()
}
\value{
A numeric vector with eight elements, each corresponding to the
angular displacement (in degrees) of a subscale, in the following order:
PA, BC, DE, FG, HI, JK, LM, NO.
}
\description{
Return a vector of angular displacements, in degrees, for eight equally
spaced circumplex scales corresponding to the circumplex octants. Can be
passed to the \code{angles} parameter of other functions in this package.
}
\examples{
octants()
}
