% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/instrument_data.R
\docType{data}
\name{csip}
\alias{csip}
\title{Circumplex Scales of Interpersonal Problems}
\format{
An object of class \code{circumplex_instrument} of length 5.
}
\source{
Boudreaux, M. J., Ozer, D. J., Oltmanns, T. F., & Wright, A. G. C.
(2018). Development and validation of the circumplex scales of
interpersonal problems. \emph{Psychological Assessment, 30}(5), 594-609.

\doi{10.1037/pas0000505}
}
\usage{
csip
}
\description{
Information about the Circumplex Scales of Interpersonal Problems (CSIP).
}
\examples{
summary(csip)
scales(csip, items = TRUE)
}
\keyword{internal}
