% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/instrument_data.R
\docType{data}
\name{iis32}
\alias{iis32}
\title{Inventory of Interpersonal Strengths, Brief Version}
\format{
An object of class \code{circumplex_instrument} of length 5.
}
\source{
Hatcher, R. L., & Rogers, D. T. (2012). The IIS-32: A brief inventory
of interpersonal strengths. \emph{Journal of Personality Assessment, 94}(6),
638-646.

\doi{10.1080/00223891.2012.681818}
}
\usage{
iis32
}
\description{
Information about the Inventory of Interpersonal Strengths, Brief Version
(IIS-32).
}
\examples{
summary(iis32)
scales(iis32, items = TRUE)
}
\keyword{internal}
