% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/instrument_data.R
\docType{data}
\name{csiv}
\alias{csiv}
\title{Circumplex Scales of Interpersonal Values}
\format{
An object of class \code{circumplex_instrument} of length 5.
}
\source{
Locke, K. D. (2000). Circumplex scales of interpersonal values:
Reliability, validity, and applicability to interpersonal problems and
personality disorders. \emph{Journal of Personality Assessment, 75}(2), 249-267.

\url{https://kennethlocke.org/CSIV/CSIV.html}
}
\usage{
csiv
}
\description{
Information about the Circumplex Scales of Interpersonal Values (CSIV).
}
\examples{
summary(csiv)
scales(csiv, items = TRUE)
}
\keyword{internal}
